pub struct ContentMetadataRecord {
pub content_reference_key: String,
pub content_metadata: Box<ContentMetadata>,
}Expand description
ContentMetadataRecord : The metadata for an A+ Content document, with additional information for content management.
Fields
content_reference_key: StringA unique reference key for the A+ Content document. A content reference key cannot form a permalink and may change in the future. A content reference key is not guaranteed to match any A+ content identifier.
content_metadata: Box<ContentMetadata>Implementations
sourceimpl ContentMetadataRecord
impl ContentMetadataRecord
sourcepub fn new(
content_reference_key: String,
content_metadata: ContentMetadata
) -> ContentMetadataRecord
pub fn new(
content_reference_key: String,
content_metadata: ContentMetadata
) -> ContentMetadataRecord
The metadata for an A+ Content document, with additional information for content management.